#!/usr/bin/python

##  This script is distributed as part of the
##	CCsolve program.
##
##	For review only.
##
##	It may not be distributed until publication.
##
##


import re
import math

from sys import argv,stdout
from os.path import exists

if argv.count('-pdb') and argv.count('-helices'):
	pos = argv.index('-pdb')
	pdb_name = argv[pos+1]
	pos = argv.index('-helices')
	num_of_helices = argv[pos+1]

else:
	print "Parameter missing"
	print "Required input parameters:"
	print "-pdb <pdb file name, string>"
	print "-helices <number of helices, int>"
	print ""

##  Function definitions

def distance(vec1, vec2):
	x = float(vec1[0]) - float(vec2[0])
	y = float(vec1[1]) - float(vec2[1])
	z = float(vec1[2]) - float(vec2[2])
	dot = ( x*x + y*y + z*z )
	return math.sqrt(dot)

## Start script

# dictionaries for N and carbonyl C positions
Cs = {}
Ns = {}

# distance until which two fragments are considered to be one helix
dist_threshold = 3.8

all_helices = []
current_helix = []

# Read coordinates from file
# The input file has to be renumbered !!!!!

pattern_C = re.compile('ATOM\s+[0-9]+\s+C\s')
pattern_N = re.compile('ATOM\s+[0-9]+\s+N\s')
for line in file(pdb_name, 'r'):
	if re.match(pattern_C, line):
		coords = line.split()[6:9]
		res_num = line.split()[5]
		Cs[res_num] = coords
	if re.match(pattern_N, line):
		coords = line.split()[6:9]
		res_num = line.split()[5]
		Ns[res_num] = coords

# Extract helices

res_pos = '1'
current_dist = dist_threshold
current_neighbor = '1'
current_helix.append('1')
gap_pos = '0'
not_finished = True
counter = 0
gaps = []

while not_finished:
	counter += 1
	for key in Ns:
			# Find the closest N to res_pos; save it's key
			if distance(Cs[res_pos],Ns[key]) < current_dist and key != res_pos:
				current_dist = distance(Cs[res_pos],Ns[key])
				current_neighbor = key
	if current_neighbor != res_pos:
			# Neighbor found
			current_helix.append(current_neighbor)
			#print current_neighbor
			#print current_helix
			if int(current_neighbor) != int(res_pos) + 1:
				# There is a discontinuity in the sequence. Keep that info:
				gap_pos = str(int(res_pos) + 1)
				gaps.append(gap_pos)
			# Update res_pos to continue from there
			res_pos = current_neighbor
			current_dist = dist_threshold

	else:
			# save the helix
			cur_hel = list(current_helix)
			if cur_hel in all_helices:
				# Nothing left to do, or got stuck in some kind of loop

				not_finished = False
				print "finished"
				break
			all_helices.append(cur_hel)
			#print all_helices
			del current_helix[:]
			current_dist = dist_threshold
			# Where to continue?
			#print all_helices[-1]
			if int(res_pos) < len(Cs) and str(int(res_pos) + 1) != (all_helices[-1])[0] :
				res_pos = str( int(res_pos) + 1 )
				current_helix.append(res_pos)
			if ( int(res_pos) == len(Cs) or str(int(res_pos) + 1) == (all_helices[-1])[0] ) and gap_pos != '0' : #and gap_pos in gaps == False :
				res_pos = str(gap_pos)
				current_helix.append(res_pos)
				gap_pos = '0'

	# escape from the script if while loop is infinite for some reason
	if counter > 30*len(Cs):
		print "ERROR: find_helix.py could not identify the longest helix."
		exit(1)

all_helices.sort(key=len)
extr_helices = 0
is_helix = False
n = 0
helix_num = 0

for Key in all_helices:
	print Key
	print '\n'


while helix_num <= num_of_helices:
	if helix_num == num_of_helices:
		break
	is_helix = True
	n -= 1
	print n
	for i in all_helices:
		overlap = set(i) & set(all_helices[n])
		print overlap
		if len(i) > len(all_helices[n]) and overlap != set([]):
			is_helix = False
			continue
	if is_helix:
		print all_helices[n]
		helix_num += 1
		name = "helix_" + str(helix_num) + ".pdb"
		# loop through the helix list i.e. residue positions and write to file
		for pos in all_helices[n]:
			for line in file(pdb_name, 'r'):
				if line.split()[5] == pos:
					with open (name, 'a') as f: f.write(line)

