#!/usr/bin/python

##  This script is distributed as part of the
##	CCsolve program.
##
##	For review only.
##
##	It may not be distributed until publication.
##
##



#!/usr/bin/python

import re
import math

from sys import exit
from sys import argv,stdout
from os.path import exists


if argv.count('-pdb') and argv.count('-helices'):
	pos = argv.index('-pdb')
	pdb_name = argv[pos+1]
	pos = argv.index('-helices')
	num_of_helices = argv[pos+1]
else:
	print "Parameter missing"
	print "Required input parameters:"
	print "-pdb <pdb file name, string>"
	print "-helices <number of helices, int>"
	print ""
	exit(1)

##  Function definitions

def distance(vec1, vec2):
	x = float(vec1[0]) - float(vec2[0])
	y = float(vec1[1]) - float(vec2[1])
	z = float(vec1[2]) - float(vec2[2])
	dot = ( x*x + y*y + z*z )
	return math.sqrt(dot)

## Start script

## If there were too many helix termini detected, you should
## inspect the pdb file and find the ones, that shouln't be
## termini. Then you can ignore using the -ignore parameter

# dictionaries for N and carbonyl C positions
Cs = {}
CAs = {}

# distance until which two fragments are considered to be one helix
dist_threshold = 4.1

all_helices = []
current_helix = []
helix_starts = []

# Read coordinates from file
# The input file has to be renumbered !!!!!

pattern_C = re.compile('ATOM\s+[0-9]+\s+C\s')
pattern_CA = re.compile('ATOM\s+[0-9]+\s+CA\s')
for line in file(pdb_name, 'r'):
	if re.match(pattern_C, line):
		coords = line.split()[6:9]
		res_num = line.split()[5]
		Cs[res_num] = coords
	if re.match(pattern_CA, line):
		coords = line.split()[6:9]
		res_num = line.split()[5]
		CAs[res_num] = coords

# Find helix starts
# Their number should equal to the desired number of helices
# All distances C to CA > threshold
is_helix_start = True
for res_pos in Cs :
	for key in CAs:
			# Find a preceeding C to res_pos; if it exists, it's NOT a helix start
			if distance(CAs[res_pos],Cs[key]) < dist_threshold and key != res_pos:
				is_helix_start = False
	if is_helix_start:
		helix_starts.append(res_pos)
	is_helix_start = True
if len(helix_starts) != int(num_of_helices) :
	print "\n ERROR  Number of helix start points is not equal to expected number of helices \n exiting ... \n"
	print "Found helix start points: "
	print helix_starts
	print "Max allowed Calpha-C distance: 4.1 Angstrom \n"
	print "This may only be fixed by manually reducing the wrong distance in e.g. pymol"
	print "File to be changed: autobuild/AutoBuild_run_1/overall_best.pdb \n"
	print "The residue positions given above are taken from autobuild_inPlace/overall_best.pdb_renum \n"
	exit(1)

print "Found helix start points: "
print helix_starts

# Extract helices

current_dist = dist_threshold
current_neighbor = '1'
not_finished = True

# Add 1st residue to 1st helix
res_pos = helix_starts[0]
current_helix.append(res_pos)
while not_finished :
	for key in Cs:
			# Find the closest CA to res_pos; save it's key
			if distance(Cs[res_pos],CAs[key]) < current_dist and key != res_pos and key not in current_helix:
				current_dist = distance(Cs[res_pos],CAs[key])
				current_neighbor = key
	# Now the closest neighbor is known
	if current_neighbor != res_pos:
			#Neighbor found
			current_helix.append(current_neighbor)
			# Update res_pos to continue from there
			res_pos = current_neighbor
			current_dist = dist_threshold
	else:
			# save the helix
			all_helices.append(list(current_helix))
			# All helices found?
			if len(all_helices) == int(num_of_helices) :
				not_finished = False
				print "finished"
				break
			# Prepare variables for next helix
			del current_helix[:]
			current_dist = dist_threshold
			res_pos = helix_starts[len(all_helices)]
			current_helix.append(res_pos)

all_helices.sort(key=len)
helix_num = 0

for helix in reversed(all_helices):
	helix_num += 1
	name = "helix_" + str(helix_num) + ".pdb"
	# loop through the helix list i.e. residue positions and write to file
	for pos in helix:
		for line in file(pdb_name, 'r'):
			if line.split()[5] == pos:
				with open (name, 'a') as f: f.write(line)

