#!/bin/bash

FRAG_SCRIPT_DIR=""  # Path to Rosetta's make_fragments.py script
                  	# E.g. /home/USER/Rosetta/tools/fragment_tools

if [ ! -s ../cc_solv.conf ]; then
	echo "No cc_solv.conf file found. If you have it somewhere else than in the directory above, please put copy there."
	exit 1
fi

name=`egrep '^seq_file' ../cc_solv.conf | awk '{print $3}' | cut -d. -f1`
seq_file=`egrep '^seq_file' ../cc_solv.conf | awk '{print $3}'`

cp ../$seq_file .

sym=$1

if [ $# -eq 0 ]; then
	read -p "What is the symmetry (dimer,C3,C4,D2,C5): " sym
fi


###########


if [ ! -s psipred_horiz ]; then
	echo "Secondary structure prediction should be run first."
	echo "This may take some minutes ..."; echo ""
	var/psipred.sh $name
	if [ ! -s psipred/psipred_horiz ]; then exit 1; fi
	cat psipred_horiz
	echo ""
	echo ""
	echo "Please remove terminal continuous parts from the sequence in $name.fasta"
	echo "Modify ONLY the fasta file in this directory!"
	echo "that are not predicted to be H with a confidence of > 5"
	echo "Then run this setup_script again."
	exit 0
fi


rm -rf psipred
echo "Create inputs directory for required Rosetta input files."
mkdir inputs
cp $seq_file inputs/

if [ "$sym" = "dimer" ]; then
	echo "Make special dimer fragments for Asymmetric Fold-and-Dock"
  var/make_fragments_Dimers.sh $name
	cp var/flags_dimer inputs/flags
	cp var/setup_init.tpb inputs/
	cp var/flexible.loop inputs/
	length=`sed -n 2p $seq_file | wc -c`
	sed -i "s/length/$length/g" inputs/setup_init.tpb
	sed -i "s/length/$length/g" inputs/flexible.loop
	end=$(($length * 2))
	sed -i "s/end/$end/g" inputs/flexible.loop
	echo "Duplicate the sequence in inputs/$name.fasta"
	sed -n 2p $seq_file >> inputs/$name.fasta
	#
else # NOT a dimeric coiled coil
	if [ ! -s fragment_files/$name\_.200.9mers ] && [ ! -s fragment_files/$name\_.200.3mers ]; then
		echo "Start to create Rosetta fragment files..."
		echo "This will take a long time ..."
		var/make_fragments.sh $name
	fi
	cp fragment_files/$name\_.200.3mers inputs
	cp fragment_files/$name\_.200.9mers inputs
	cp var/flags inputs/
	cp var/broker.setup inputs/
	cp var/sym$sym.def inputs/
	if [ ! -e inputs/$name\_.200.3mers ] || [ ! -e inputs/$name\_.200.9mers ]; then
		echo "No fragment files found in inputs"
		exit 1
	fi
fi


echo "Fragment files are copied to inputs"
cd inputs
sed -i "s/name/$name/g" flags
database=`egrep '^rosetta_database' ../../cc_solv.conf | awk '{print $3}'`
echo $database | sed -e 's/\//\\\//g'i > tmp
database=`cat tmp`
rm tmp
sed -i "s/rosetta_database/$database/g" flags
if [ "$sym" != "dimer" ]; then
	case $sym in
	C3)
		sed -i "s/XX/C3/g" flags ;;
	C4)
		sed -i "s/XX/C4/g" flags ;;
	D2)
		sed -i "s/XX/D2/g" flags ;;
	C5)
		sed -i "s/XX/C5/g" flags ;;
	esac
fi
cd ../

rm -rf fragment_files

echo ""
echo "**************************************************************************************************************"
echo "All required input files for Rosetta should now be present in ./inputs"
echo "Copy the inputs directory to wherever you intend to run Rosetta"
echo ""
echo "Example Rosetta commandline:"
echo "minirosetta.linuxgccrelease @inputs/flags -out::file:silent 0.out -out::scorefile 0.fsc -nstruct 250 -mute all"
echo ""
echo "When running Rosetta on a cluster, don't forget to change the database location in inputs/flags!!"
echo "**************************************************************************************************************"
echo ""
