#!/bin/bash

#####################################
#																		#
#  The script runs psipred to				#
#  identify terminal regions that 	#
#  are likely non-helical						#
#																		#
#####################################

# Required:
# - Blast installation
# - Psipred installation
# - ncbi non-redundant sequence database


FRAG_SCRIPT_DIR=`grep FRAG_SCRIPT setup_rosetta.sh | cut -d\" -f2`

if [ $FRAG_SCRIPT_DIR == "" ]; then
	echo "Please open this psipred.sh file and enter the path to the Rosetta fragment tools."
fi

if [ ! -e $FRAG_SCRIPT_DIR/blast/bin/blastpgp ]; then
	echo "blast/bin/blastpgp is missing in $FRAG_SCRIPT_DIR . Run make_fragments.py inside $FRAG_SCRIPT_DIR without parameters. This should install all required files."
	echo "You can also set the paths to blast, nr database and psipred within the Rosetta's make_fragments.py script, in case you have those programms instaled somewhere else."
	exit 1
elif [ ! -e $FRAG_SCRIPT_DIR/psipred/bin/psipred ]; then
	echo "psipred/bin/psipred is missing in $FRAG_SCRIPT_DIR . Run make_fragments.py inside $FRAG_SCRIPT_DIR without parameters. This should install all required files."
	echo "You can also set the paths to blast, nr database and psipred within the Rosetta's make_fragments.py script, in case you have those programms instaled somewhere else."
	exit 1
elif [ ! -e $FRAG_SCRIPT_DIR/databases/nr ]; then
	echo "database/nr is missing in $FRAG_SCRIPT_DIR . Run make_fragments.py inside $FRAG_SCRIPT_DIR without parameters. This should install all required files."
	echo "You can also set the paths to blast, nr database and psipred within the Rosetta's make_fragments.py script, in case you have those programms instaled somewhere else."
	exit 1
fi

name=$1

mkdir psipred
cd psipred

ln -s ../$name.fasta "$name"_.fasta
$FRAG_SCRIPT_DIR/blast/bin/blastpgp -a 8  -t 1 -i "$name"_.fasta -F F -j2 -o "$name"_.blast -d $FRAG_SCRIPT_DIR/databases/nr -v10000 -b10000 -K1000 -h0.0009 -e0.0009 -C "$name"_.chk -Q "$name"_.pssm
$FRAG_SCRIPT_DIR/blast/bin/blastpgp -a 8  -t 1 -b10000 -v10000 -j3 -h0.001 -d $FRAG_SCRIPT_DIR/databases/nr_pfilt -i "$name"_.fasta -C sstmp.chk -Q sstmp.ascii -o ss_blast
#$FRAG_SCRIPT_DIR/blast/bin/blastpgp -a 8  -t 1 -b10000 -v10000 -j3 -h0.001 -d $FRAG_SCRIPT_DIR/databases/filtnr -i "$name"_.fasta -C sstmp.chk -Q sstmp.ascii -o ss_blast
echo "$name"_.fasta > psitmp.sn
echo sstmp.chk > psitmp.pn
$FRAG_SCRIPT_DIR/blast/bin/makemat -P psitmp
if [ -e $FRAG_SCRIPT_DIR/psipred/data/weights.dat4 ]; then
	$FRAG_SCRIPT_DIR/psipred/bin/psipred sstmp.mtx $FRAG_SCRIPT_DIR/psipred/data/weights.dat $FRAG_SCRIPT_DIR/psipred/data/weights.dat2 $FRAG_SCRIPT_DIR/psipred/data/weights.dat3 $FRAG_SCRIPT_DIR/psipred/data/weights.dat4 > psipred_ss
else
	$FRAG_SCRIPT_DIR/psipred/bin/psipred sstmp.mtx $FRAG_SCRIPT_DIR/psipred/data/weights.dat $FRAG_SCRIPT_DIR/psipred/data/weights.dat2 $FRAG_SCRIPT_DIR/psipred/data/weights.dat3 > psipred_ss
fi
$FRAG_SCRIPT_DIR/psipred/bin/psipass2 $FRAG_SCRIPT_DIR/psipred/data/weights_p2.dat 1 1 1 psipred_ss2 psipred_ss > psipred_horiz
cp psipred_horiz ../
cd ../
echo "Result writen to psipred_horiz"
cat psipred_horiz

