#!/bin/bash


##  This script is distributed as part of the
##	CCsolve program.
##
##	For review only.
##
##	It may not be distributed until publication.
##
##



#!/bin/bash

#########################################################################
#
# This script prepares input files for model building using autobuild.
# Author: Sebastian Rämisch

#####################################
# import infos from config file

echo
echo "*******************"
echo "* Start Autobuild *"
echo "*******************"
echo

name=`egrep '^seq_file' cc_solv.conf | awk '{print $3}' | cut -d. -f1`
seq_file=`egrep '^seq_file' cc_solv.conf | awk '{print $3}'`
scripts=`egrep '^scripts' cc_solv.conf | awk '{print $3}'`
chains=`egrep '^helices' cc_solv.conf | awk '{print $3}'`
mtz=`egrep '^mtz_file' cc_solv.conf | awk '{print $3}'`


if [ ! -f results_refine.txt ]; then
	echo "No result file from phenix.refine found"
	exit 1
fi

# get the best superimposed input from refine to use in autoBuild
best=`sed -n 2p results_refine.txt | awk '{print $2}' | sed 's/_refine_001//'`
best_dir=`sed -n 2p results_refine.txt | cut -d/ -f2`
file=refine/$best_dir/PHASER.1_superimposed.pdb
model_name=`echo $file | cut -d/ -f3`
echo "Best input for refinement was $best"
mkdir autobuild
cp $file autobuild
cp $mtz autobuild
sed -n '2p' $seq_file > autobuild/$name.seq
cd autobuild

cmd1="phenix.autobuild data=$mtz model=$model_name seq_file=$name.seq s_annealing=True rebuild_in_place=False nproc=4"
echo "cmd1: $cmd1"
nice $cmd1 > autobuild_1.log &
pid=`echo $!`
echo "ps aux | grep $pid  | grep phenix | wc -l" > ps_cmd1
printf "Check, whether autobuild 1 is still running with:\n
ps aux | grep $pid  | grep phenix | wc -l\n\n"
wait $pid

echo
echo "**********************"
echo "* Finished Autobuild *"
echo "**********************"
echo

